@@ -1,9 +1,17 @@
 # flake8: noqa
 
-__all__ = ["CaverphoneOne", "CaverphoneTwo", "Editex", "Levenshtein", "Typox"]
+__all__ = [
+    "CaverphoneOne",
+    "CaverphoneTwo",
+    "Editex",
+    "Levenshtein",
+    "Soundex",
+    "Typox",
+]
 
 from .caverphone_one import CaverphoneOne
 from .caverphone_two import CaverphoneTwo
 from .editex import Editex
 from .levenshtein import Levenshtein
+from .soundex import Soundex
 from .typox import Typox
